@@ -110,15 +110,16 @@
 //! It is recommended to not use the encoder directly but instead pass it onto the higher level
 //! abstractions like `CompressorWriter<W>` or `DecompressorReader<R>`.
 
-#![warn(missing_docs)]
+#![deny(warnings)]
+#![deny(missing_docs)]
 
 pub mod decode;
 pub mod encode;
 
 pub use encode::BrotliEncoder;
 pub use encode::BrotliEncoderOptions;
-pub use encode::CompressorWriter;
 pub use encode::CompressorReader;
+pub use encode::CompressorWriter;
 
 pub use decode::BrotliDecoder;
 pub use decode::BrotliDecoderOptions;
@@ -126,9 +127,9 @@ pub use decode::DecompressorReader;
 pub use decode::DecompressorWriter;
 
 use brotlic_sys::*;
+use std::io::ErrorKind;
 use std::os::raw::c_int;
 use std::{error, fmt, io};
-use std::io::ErrorKind;
 
 /// Quality level of the brotli compression
 ///
@@ -278,9 +279,9 @@ impl Default for Quality {
 /// Its maximum size is currently limited to 16 MiB, as specified in RFC7932 (Brotli proper).
 /// Larger window sizes are supported via [`LargeWindowSize`], however note that decompression
 /// support for these have to be explicitly enabled. This can be configured via
-/// [`non_std_window_size_support`] for the matching [`BrotliDecoder`].
+/// [`large_window_size`] for the matching [`BrotliDecoder`].
 ///
-/// [`non_std_window_size_support`]: decode::BrotliDecoderOptions::non_std_window_size_support()
+/// [`large_window_size`]: decode::BrotliDecoderOptions::large_window_size()
 /// [`BrotliDecoder`]: decode::BrotliDecoder
 #[derive(Debug, Copy, Clone, Eq, PartialEq, Ord, PartialOrd)]
 pub struct WindowSize(u8);
@@ -341,9 +342,9 @@ impl WindowSize {
     /// This is currently limited to 24 bits (16 MiB) due to RFC7932 (Brotli proper). To use larger
     /// sliding window sizes, please refer to [`LargeWindowSize`]. Note however that explicit
     /// support has to be enabled by the decoder. This is supported by enabling
-    /// [`non_std_window_size_support`] when constructing a [`BrotliDecoder`].
+    /// [`large_window_size`] when constructing a [`BrotliDecoder`].
     ///
-    /// [`non_std_window_size_support`]: decode::BrotliDecoderOptions::non_std_window_size_support()
+    /// [`large_window_size`]: decode::BrotliDecoderOptions::large_window_size()
     /// [`BrotliDecoder`]: decode::BrotliDecoder
     ///
     /// # Examples
@@ -442,10 +443,10 @@ impl TryFrom<LargeWindowSize> for WindowSize {
 /// The large sliding window size (in bits) to use for compression.
 ///
 /// Note that using a large sliding window size for a particular compressor requires explicit
-/// support by the decompressor. This is supported by enabling [`non_std_window_size_support`] when
+/// support by the decompressor. This is supported by enabling [`large_window_size`] when
 /// constructing a [`BrotliDecoder`].
 ///
-/// [`non_std_window_size_support`]: decode::BrotliDecoderOptions::non_std_window_size_support()
+/// [`large_window_size`]: decode::BrotliDecoderOptions::large_window_size()
 /// [`BrotliDecoder`]: decode::BrotliDecoder
 #[derive(Debug, Copy, Clone, Eq, PartialEq, Ord, PartialOrd)]
 pub struct LargeWindowSize(u8);
@@ -666,7 +667,7 @@ impl BlockSize {
     /// assert_eq!(best_size, BlockSize::best());
     /// # Ok::<(), brotlic::ParameterSetError>(())
     /// ```
-    pub fn best() -> BlockSize {
+    pub const fn best() -> BlockSize {
         BlockSize(BROTLI_MAX_INPUT_BLOCK_BITS)
     }
 
@@ -685,7 +686,7 @@ impl BlockSize {
     /// assert_eq!(worst_size, BlockSize::worst());
     /// # Ok::<(), brotlic::ParameterSetError>(())
     /// ```
-    pub fn worst() -> BlockSize {
+    pub const fn worst() -> BlockSize {
         BlockSize(BROTLI_MIN_INPUT_BLOCK_BITS)
     }
 
@@ -747,9 +748,6 @@ impl From<CompressError> for io::Error {
     }
 }
 
-/// a specialized [`Result`] type returned by [`compress`].
-pub type CompressionResult<T> = Result<T, CompressError>;
-
 /// An error returned by [`decompress`].
 #[derive(Debug)]
 pub struct DecompressError;
@@ -768,9 +766,6 @@ impl From<DecompressError> for io::Error {
     }
 }
 
-/// a specialized [`Result`] type returned by [`decompress`].
-pub type DecompressionResult<T> = Result<T, DecompressError>;
-
 /// An error returned by [`BrotliEncoderOptions::build`] and [`BrotliDecoderOptions::build`]
 ///
 /// [`BrotliEncoderOptions::build`]: encode::BrotliEncoderOptions::build
@@ -806,20 +801,15 @@ pub enum ParameterSetError {
 impl fmt::Display for ParameterSetError {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         match self {
-            ParameterSetError::Generic =>
-                f.write_str("invalid parameter"),
-            ParameterSetError::InvalidPostfix =>
-                f.write_str("invalid number of postfix bits"),
-            ParameterSetError::InvalidDirectDistanceCodes =>
-                f.write_str("invalid number of direct distance codes"),
-            ParameterSetError::InvalidStreamOffset =>
-                f.write_str("stream offset was out of range"),
-            ParameterSetError::InvalidQuality =>
-                f.write_str("quality out of range"),
-            ParameterSetError::InvalidWindowSize =>
-                f.write_str("window size out of range"),
-            ParameterSetError::InvalidBlockSize =>
-                f.write_str("block size out of range"),
+            ParameterSetError::Generic => f.write_str("invalid parameter"),
+            ParameterSetError::InvalidPostfix => f.write_str("invalid number of postfix bits"),
+            ParameterSetError::InvalidDirectDistanceCodes => {
+                f.write_str("invalid number of direct distance codes")
+            }
+            ParameterSetError::InvalidStreamOffset => f.write_str("stream offset was out of range"),
+            ParameterSetError::InvalidQuality => f.write_str("quality out of range"),
+            ParameterSetError::InvalidWindowSize => f.write_str("window size out of range"),
+            ParameterSetError::InvalidBlockSize => f.write_str("block size out of range"),
         }
     }
 }
@@ -869,7 +859,7 @@ pub fn compress(
     quality: Quality,
     window_size: WindowSize,
     mode: CompressionMode,
-) -> CompressionResult<usize> {
+) -> Result<usize, CompressError> {
     let mut output_size = output.len();
 
     let res = unsafe {
@@ -945,7 +935,7 @@ pub fn compress_bound(input_size: usize, quality: Quality) -> Option<usize> {
 /// # Ok::<(), std::io::Error>(())
 /// ```
 #[doc(alias = "BrotliDecoderDecompress")]
-pub fn decompress(input: &[u8], output: &mut [u8]) -> DecompressionResult<usize> {
+pub fn decompress(input: &[u8], output: &mut [u8]) -> Result<usize, DecompressError> {
     let mut output_size = output.len();
 
     let res = unsafe {
@@ -1012,4 +1002,3 @@ impl<I> fmt::Display for IntoInnerError<I> {
         self.error().fmt(f)
     }
 }
-
